==> banshee-1-1.3.1.tar.bz2: banshee-1-1.3.1/src/Core/Banshee.Services/Banshee.Hardware/IVolume.cs <==
//
// IVolume.cs
//
// Author:
//   Aaron Bockover <abockover@novell.com>
//
// Copyright (C) 2008 Novell, Inc.
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
//
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;

namespace Banshee.Hardware
{
    public interface IVolume : IDevice
    {
        string DeviceNode { get; }
        string MountPoint { get; }
        bool IsReadOnly { get; }
        ulong Capacity { get; }
        long Available { get; }
        new IBlockDevice Parent { get; }

        bool ShouldIgnore { get; }
        string FileSystem { get; }
        
        bool CanEject { get; }
        void Eject ();
        
        bool CanUnmount { get; }
        void Unmount ();
    }
}

==> banshee-1-1.9.3.tar.bz2: banshee-1-1.9.3/src/Core/Banshee.Services/Banshee.Hardware/IVolume.cs <==
//
// IVolume.cs
//
// Author:
//   Aaron Bockover <abockover@novell.com>
//
// Copyright (C) 2008 Novell, Inc.
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
//
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;

namespace Banshee.Hardware
{
    public interface IVolume : IDevice
    {
        string DeviceNode { get; }
        string MountPoint { get; }
        bool IsMounted { get; }
        bool IsReadOnly { get; }
        ulong Capacity { get; }
        long Available { get; }
        IBlockDevice Parent { get; }

        bool ShouldIgnore { get; }
        string FileSystem { get; }

        bool CanEject { get; }
        void Eject ();

        bool CanMount { get; }
        void Mount ();

        bool CanUnmount { get; }
        void Unmount ();
    }
}
